@@ -6,6 +6,7 @@
  * Copyright 2002-2004 Darren Bounds <dbounds@intrusense.com>
  * Copyright 2013      Mats Erik Andersson <gnu@gisladisker.se>
  * Copyright 2016-2017 Robert Krause <ruport@f00l.de>
+ * Copyright 2017      Edward Betts <edward@4angle.com>
  * Copyright 2017      Sharad B
  *
  * This program is free software; you can redistribute it and/or
@@ -127,7 +128,7 @@ struct icmp4hdr_opts
     u_int8_t *mask;                     /* icmp4 mask */
 
     u_int32_t otime;                    /* original timestamp */
-    u_int32_t rtime;                    /* recieved timestamp */
+    u_int32_t rtime;                    /* received timestamp */
     u_int32_t ttime;                    /* transmit timestamp */
 } g_i4hdr_o;
 
